import { world } from "@minecraft/server";


world.afterEvents.entityDie.subscribe((event) => {
  const entity = event.deadEntity;

  
  try {
    const { x, y, z } = entity.location; 
    entity.dimension.runCommandAsync(`summon fireworks_rocket ${x} ${y} ${z}`);
  } catch (error) {
    console.error(`Failed to summon fireworks: ${error}`);
  }
});




world.afterEvents.entityHurt.subscribe((event) => {
  const attacker = event.damageSource.damagingEntity;

  
  if (attacker && attacker.typeId === "minecraft:player") {
    try {


      const axes = [
        "wooden_sword",
                "stone_sword",
                "iron_sword",
                "golden_sword",
                "diamond_sword",
                "netherite_sword"
      ];

      for (const axe of axes) {
        attacker.runCommandAsync(
          `effect @e[hasitem={item=${axe},location=slot.weapon.mainhand}] weakness 1 5 true`
        );
        attacker.runCommandAsync(
          `effect @e[hasitem={item=${axe},location=slot.weapon.mainhand}] mining_fatigue 1 15 true`
        );
      }
    } catch (error) {
      console.error(`Failed to run command: ${error}`);
    }
  }
});


world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.blockComponentRegistry.registerCustomComponent('zc_hblock:trigger', {
  onTick: e => { e.dimension.runCommand("effect @a health_boost 15 4 true"); },
});

});






world.afterEvents.playerPlaceBlock.subscribe(async (event) => {
    const player = event.player; 
    const block = event.block;


    if (block.typeId === "zc:health_block") {
        try {
          
            await player.runCommandAsync(`tickingarea add ~ ~ ~ ~ ~ ~`);
            player.sendMessage("Ticking area added successfully!");
        } catch (error) {
            console.error(`Failed to add ticking area: ${error}`);
            player.sendMessage("Failed to add ticking area. Check the console for details.");
        }
    }
});




world.afterEvents.entityDie.subscribe((event) => {
  const entity = event.deadEntity;

  if (!entity || entity.typeId !== "minecraft:player") return;

  try {
    const loc = entity.location;
    const dim = entity.dimension;

    if (!loc || !dim) return;

    
    dim.runCommandAsync(`playsound mob.enderdragon.growl @a ${loc.x} ${loc.y} ${loc.z} 1 1`);
  } catch (error) {
    console.warn(`Failed to play sound: ${error}`);
  }
});